@@ -9,7 +9,7 @@ use Mojo::Util qw/trim/;
 
 use v5.10.1;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 our @CARP_NOT;
 
@@ -273,7 +273,9 @@ sub sign {
   if ($mkey) {
 
     # No valid private key
-    return unless $mkey->d;
+    unless ($mkey->d) {
+      carp 'Unable to sign without private exponent' and return;
+    };
 
     # Compute signature for base string
     my $msig = $mkey->sign( $data );
@@ -934,7 +936,7 @@ See the test suite for further information.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2014, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2012-2015, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the terms of the Artistic License version 2.0.
